@@ -77,7 +77,7 @@ stream_component_open(AVFormatContext *fc,
     if(stream_index < 0 || stream_index >= fc->nb_streams)
         return -1;
 
-    enc = &fc->streams[stream_index]->codec;
+    enc = fc->streams[stream_index]->codec;
     codec = avcodec_find_decoder(enc->codec_id);
     if(!codec)
         return -1;
@@ -99,7 +99,9 @@ ffmpeg_open_for_reading(struct file *file,
     int err, i, audio_index = -1;
 
     memset(&format_params, 0, sizeof(format_params));
-    format_params.image_format = NULL;
+    //
+
+    //    format_params.image_format = NULL;
     format_params.initial_pause = 1; /* we force a pause when starting an RTSP
                                         stream */
 
@@ -117,7 +119,7 @@ ffmpeg_open_for_reading(struct file *file,
     }
     
     for(i = 0; i < fc->nb_streams; i++) {
-        AVCodecContext *enc = &fc->streams[i]->codec;
+        AVCodecContext *enc = fc->streams[i]->codec;
         switch(enc->codec_type) {
         case CODEC_TYPE_AUDIO:
             DEBUG("found audio stream %d\n", i);
@@ -146,7 +148,7 @@ ffmpeg_open_for_reading(struct file *file,
         return cmd_new_error_val("Could not open audio stream");
     }        
 
-    codec = avcodec_find_decoder(fc->streams[audio_index]->codec.codec_id);
+    codec = avcodec_find_decoder(fc->streams[audio_index]->codec->codec_id);
     snprintf(ffmpeg_data->format_name, sizeof(ffmpeg_data->format_name),
              "%s/%s", fc->iformat->name, codec->name);
 
@@ -155,8 +157,8 @@ ffmpeg_open_for_reading(struct file *file,
     ffmpeg_data->audio_stream = fc->streams[audio_index];
 
     params->sample_type = SAMPLE_TYPE_INT_16;
-    params->sample_rate = ffmpeg_data->audio_stream->codec.sample_rate;
-    params->channels = ffmpeg_data->audio_stream->codec.channels;
+    params->sample_rate = ffmpeg_data->audio_stream->codec->sample_rate;
+    params->channels = ffmpeg_data->audio_stream->codec->channels;
     params->frame_count = -1;
 
     av_read_play(fc);
@@ -181,7 +183,7 @@ ffmpeg_read(struct file *file,
             void *buf,
             long count) {
     struct ffmpeg_data *ffmpeg_data = file->driver_data;
-    int err, frame_size, len;
+    int err, frame_size = (AVCODEC_MAX_AUDIO_FRAME_SIZE * 3) / 2, len;
     long copied = 0;
 
     /* 
@@ -227,14 +229,14 @@ ffmpeg_read(struct file *file,
          * the decode buffer.
          */
 
-        len = avcodec_decode_audio(&ffmpeg_data->audio_stream->codec,
-                                   (int16_t *)ffmpeg_data->decode_buf,
-                                   &frame_size,
-                                   (ffmpeg_data->packet.data + 
-                                    ffmpeg_data->packet_offset), 
-                                   (ffmpeg_data->packet.size - 
-                                    ffmpeg_data->packet_offset));
-
+        len = avcodec_decode_audio2(ffmpeg_data->audio_stream->codec,
+                                    (int16_t *)ffmpeg_data->decode_buf,
+                                    &frame_size,
+                                    (ffmpeg_data->packet.data + 
+                                     ffmpeg_data->packet_offset), 
+                                    (ffmpeg_data->packet.size - 
+                                     ffmpeg_data->packet_offset));
+        
         if(len >= 0) {
 
             /* Something in decode buffer. */
@@ -274,14 +276,14 @@ ffmpeg_read(struct file *file,
      * could save a memcpy() here, but this is cleaner.
      */
 
-    copied = MIN(count * ffmpeg_data->audio_stream->codec.channels * 2, 
+    copied = MIN(count * ffmpeg_data->audio_stream->codec->channels * 2, 
                  ffmpeg_data->decode_buf_avail);
     memcpy(buf, ffmpeg_data->decode_buf + ffmpeg_data->decode_buf_offset,
            copied);
     ffmpeg_data->decode_buf_offset += copied;
     ffmpeg_data->decode_buf_avail -= copied;
 
-    return copied / (ffmpeg_data->audio_stream->codec.channels * 2);
+    return copied / (ffmpeg_data->audio_stream->codec->channels * 2);
 }
 
 static long
@@ -299,7 +301,7 @@ ffmpeg_close(struct file *file) {
     if(ffmpeg_data->packet.data) 
         av_free_packet(&ffmpeg_data->packet);
         
-    enc = &ffmpeg_data->audio_stream->codec;
+    enc = ffmpeg_data->audio_stream->codec;
     avcodec_close(enc);
     av_close_input_file(ffmpeg_data->format_context);
 
