@@ -465,10 +465,10 @@ set_hwparams(struct player *p,
     }
     DEBUG("rrate: %u\n", rrate);
 
-    if (rrate != rate) {
-        FAIL("Rate doesn't match (requested %iHz, got %iHz)\n", rate, rrate);
-        return -EINVAL;
-    }
+    //    if (rrate != rate) {
+    //        FAIL("Rate doesn't match (requested %iHz, got %iHz)\n", rate, rrate);
+    //        return -EINVAL;
+    //    }
     dd->sample_rate = rrate;
 
     DEBUG("buffer time: %d\n", buffer_time);
@@ -513,15 +513,6 @@ set_hwparams(struct player *p,
              snd_strerror(err));
         return err;
     }
-    err = snd_pcm_hw_params_get_period_size(params, &dd->period_size, &dir);
-    if (err < 0) {
-        FAIL("Unable to get period size for %s: %s\n", 
-             snd_pcm_name(handle),
-             snd_strerror(err));
-        return err;
-    }
-
-    DEBUG("period_size: %ld\n", dd->period_size);
 
     /* write the parameters to device */
     err = snd_pcm_hw_params(handle, params);
@@ -531,6 +522,17 @@ set_hwparams(struct player *p,
              snd_strerror(err));
         return err;
     }
+
+    err = snd_pcm_hw_params_get_period_size(params, &dd->period_size, 0);
+    if (err < 0) {
+        FAIL("Unable to get period size for %s: %s\n", 
+             snd_pcm_name(handle),
+             snd_strerror(err));
+        return err;
+    }
+
+    DEBUG("period_size: %ld\n", dd->period_size);
+
     return 0;
 }
 
@@ -547,7 +549,7 @@ alsa_init_device(struct player *p,
                  int mode) {
     struct alsa_data *dd = p->driver_data;
     int err;
-
+    snd_pcm_info_t *info;
     *handle = NULL;
 
     if((err = snd_pcm_open(handle, dev, stream, mode)) < 0) {
@@ -555,6 +557,19 @@ alsa_init_device(struct player *p,
         view_set_transient(p->shl->view, MSG_ERR, "Can't open %s", dev);
         return err;
     }
+
+
+        snd_pcm_info_malloc(&info);
+
+        snd_pcm_info(*handle, info);
+
+        snd_pcm_sync_id_t sync_id = snd_pcm_info_get_sync(info);
+
+        DEBUG("  sync_id - 0x%x,0x%x,0x%x,0x%x\n", sync_id.id32[0], sync_id.id32[1], sync_id.id32[2], sync_id.id32[3]);
+
+        snd_pcm_info_free(info);
+
+
     if((err = set_hwparams(p,
                            *handle, 
                            hwparams, 
@@ -617,6 +632,9 @@ alsa_open(struct player *p) {
     snd_pcm_sw_params_t *play_swparams;
     snd_pcm_hw_params_t *record_hwparams;
     snd_pcm_sw_params_t *record_swparams;
+    snd_pcm_info_t *play_info;
+    snd_pcm_info_t *rec_info;
+
 
     snd_pcm_hw_params_alloca(&play_hwparams);
     snd_pcm_sw_params_alloca(&play_swparams);
@@ -663,6 +681,21 @@ alsa_open(struct player *p) {
             snd_pcm_close(dd->play_handle);
             return 1;
         }
+
+        snd_pcm_info_malloc(&play_info);
+        snd_pcm_info_malloc(&rec_info);
+
+        snd_pcm_info(dd->play_handle, play_info);
+        snd_pcm_info(dd->record_handle, rec_info);
+
+        snd_pcm_sync_id_t play_sync_id = snd_pcm_info_get_sync(play_info);
+        snd_pcm_sync_id_t rec_sync_id = snd_pcm_info_get_sync(rec_info);
+
+        snd_pcm_info_free(play_info);
+        snd_pcm_info_free(rec_info);
+
+        DEBUG("  play_sync_id - 0x%x,0x%x,0x%x,0x%x\n", play_sync_id.id32[0], play_sync_id.id32[1], play_sync_id.id32[2], play_sync_id.id32[3]);
+        DEBUG("  rec_sync_id - 0x%x,0x%x,0x%x,0x%x\n", rec_sync_id.id32[0], rec_sync_id.id32[1], rec_sync_id.id32[2], rec_sync_id.id32[3]);
         
         if((err = snd_pcm_link(dd->play_handle, dd->record_handle))) {
             view_set_transient(p->shl->view, MSG_ERR, "Device link error");
