@@ -23,7 +23,7 @@
 #include <gui_file_selector.h>
 
 static void
-gui_file_selector_destroy(GtkFileSelection *fs) {
+gui_file_selector_destroy(GtkWidget *fs) {
     void (*destroy_handler)(void *user_data) = 
         g_object_get_data(G_OBJECT(fs), "destroy_handler");
     void *user_data = g_object_get_data(G_OBJECT(fs), "user_data");
