@@ -23,6 +23,7 @@
 
 #include <config.h>
 #include <audiofile.h>
+#include <samplerate.h>
 #include "shell.h"
 
 struct _shell;
@@ -183,6 +184,13 @@ struct player {
     struct player_state *state;
     struct player_state _state_storage;
 
+    /* Sample rate conversion. */
+
+    void *playback_resamplebuf_in;
+    void *playback_resamplebuf_out;
+    SRC_STATE *sample_rate_converter;
+    SRC_DATA sample_rate_converter_data;
+    long long resample_output_frames_played;
 };
 
 /**
