@@ -1,6 +1,6 @@
 /*
  * GNUsound - a sound editor for GNOME.
- * Copyright (C) 2002-2004  Pascal Haakmat <a.haakmat@chello.nl>
+ * Copyright (C) 2002-2004  Pascal Haakmat <pascal@gnu.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1303,12 +1303,12 @@ snd_set_name(snd *sr,
  *
  * @param sr The snd to get the audio from.
  * @param fb_targets A pointer array, one for each track, to store the
- * audio in. Each target must be big enough to hold at least frame_count 
- * frames.
+ * audio in. Each array must be big enough to hold at least frame_count 
+ * samples.
  * @param channel_map Which channels to get; the others receive silence.
  * @param frame_offset Position to get samples from.
  * @param frame_count How many frames to get.
- * @return Largest number of frames actually retrieved.
+ * @return Largest number of samples actually retrieved.
  */
 
 AFframecount
@@ -1354,14 +1354,34 @@ snd_getn(snd *sr,
 AFframecount
 snd_geti(snd *sr,
          void *fb_i,
-         void *fb_n[],
          track_map_t channel_map,
          AFframecount frame_offset,
          AFframecount frame_count) {
-    AFframecount r;
-    r = snd_getn(sr, fb_n, channel_map, frame_offset, frame_count);
-    sample_interleave(sr->sample_type, fb_i, fb_n, sr->channels, 0, r);
-    return r;
+    AFframecount high = 0, r;
+    int i;
+
+    if(error_thrown(&sr->error))
+        return 0;
+
+    rwlock_rlock(&sr->rwl);
+
+    memset(fb_i, '\0', frame_count * 
+           sample_get_width(sr->sample_type) * sr->channels);
+
+    for(i = 0; i < sr->channels; i++) {
+        if((1 << i) & channel_map) {
+            r = track_get_samples(sr->tracks[i],
+                                  fb_i,
+                                  frame_offset,
+                                  frame_count);
+            if(r > high)
+                high = r;
+        }
+    }
+
+    rwlock_runlock(&sr->rwl);
+    
+    return high;
 }
 
 /**
